import './App.css';
import { useEffect, useState } from 'react';
import io from 'socket.io-client';

const socket = io(`http://localhost:8888`);

let ws_ts;

function App() {

  const [file, setFile] = useState();
  const [httpLog, setHttpLog] = useState([]);
  const [wsLog, setWsLog] = useState([]);


  async function sendHTTP() {
    const now = Date.now();
    const formData = new FormData();
    formData.append('file', file);

    const res = await fetch(`http://localhost:7777/http`, {method: 'POST', body: formData});
    const d = Date.now() - now;

    const blob = await res.blob();

    const url = URL.createObjectURL(blob);
    setHttpLog(p => [...p, d]);
    const a = document.createElement('a');
    a.href = url;
    a.download = file.name;
    a.click();

    URL.revokeObjectURL(url);
  }

  function sendWS() {
    ws_ts = Date.now();
    const reader = new FileReader();
    reader.onload = () => {
      socket.emit('sendFile', {
            filename: file.name,
            content: reader.result,
        });
    };
    reader.readAsDataURL(file);
  }

  useEffect(() => {
    const handleReceiveFile = (data) => {
      const { filename, content } = data;
      const blob = new Blob([content]);
      const url = URL.createObjectURL(blob);
      const d = Date.now() - ws_ts;
      const a = document.createElement('a');
      setWsLog(p => [...p, d]);
      a.href = url;
      a.download = filename;
      a.click();
      
      URL.revokeObjectURL(url);
    }
    socket.on('receiveFile', handleReceiveFile);

    return () => {
      socket.off('receiveFile', handleReceiveFile);
    };
  }, []);

  return (
    <div className="App">
      <input type='file' onChange={e => setFile(e.target.files[0])}/>
      <div>
        <h4>HTTP</h4>
        <button onClick={sendHTTP}>Send</button>
        <div>
          {httpLog.map((t, i) => <span key={i} style={{marginRight: '10px'}}>{t}</span>)}
        </div>
        <strong>
          {httpLog.reduce((p, c) => (p + c), 0)/httpLog.length || 0}
        </strong>
      </div>
      <div>
        <h4>WS</h4>
        <button onClick={sendWS}>Send</button>
        <div>
          {wsLog.map((t, i) => <span key={i} style={{marginRight: '10px'}}>{t}</span>)}
        </div>
        <strong>
          {wsLog.reduce((p, c) => (p + c), 0)/wsLog.length || 0}
        </strong>
      </div>
    </div>
  );
}

export default App;
